@@ -1,6 +1,6 @@
 package Facebook::Graph;
 BEGIN {
-  $Facebook::Graph::VERSION = '0.0402';
+  $Facebook::Graph::VERSION = '0.0500';
 }
 
 use Any::Moose;
@@ -8,6 +8,7 @@ use Facebook::Graph::AccessToken;
 use Facebook::Graph::Authorize;
 use Facebook::Graph::Query;
 use Facebook::Graph::Picture;
+use Facebook::Graph::Publish::Post;
 
 has app_id => (
     is      => 'ro',
@@ -77,6 +78,17 @@ sub picture {
     return Facebook::Graph::Picture->new( object_name => $object_name );
 }
 
+sub publish_post {
+    my ($self) = @_;
+    my %params;
+    if ($self->has_access_token) {
+        $params{access_token} = $self->access_token;
+    }
+    if ($self->has_secret) {
+        $params{secret} = $self->secret;
+    }
+    return Facebook::Graph::Publish::Post->new( %params );
+}
 
 
 no Any::Moose;
@@ -88,7 +100,7 @@ Facebook::Graph - A fast and easy way to integrate your apps with Facebook.
 
 =head1 VERSION
 
-version 0.0402
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -222,6 +234,14 @@ An profile id like C<sarahbownds> or an object id like C<16665510298> for the Pe
 
 
 
+=head2 publish_post ( )
+
+Creates a L<Facebook::Graph::Publish::Post> object, which can be used to publish data to a user's feed/wall.
+
+
+
+
+
 
 =head2 convert_sessions ( sessions )
 
